import json

import pytest

from ey_commerce_lib.dxm.constant.order import ORDER_SEARCH_APPROVAL_BASE_FORM, \
    ORDER_SEARCH_PENDING_PROCESSING_BASE_FORM, ORDER_SEARCH_SELF_WAREHOUSE_BASE_FORM, \
    ORDER_SEARCH_OUT_OF_STOCK_BASE_FORM, ORDER_SEARCH_HAVE_GOODS_BASE_FORM
from ey_commerce_lib.dxm.main import DxmClient
from ey_commerce_lib.dxm.schemas.tracking import TrackingPageListQuery
from ey_commerce_lib.dxm.schemas.warehouse import WarehouseProductQuery
from ey_commerce_lib.dxm.utils.mark import get_custom_mark_content_list_by_data_custom_mark, \
    generate_add_or_update_user_comment_data_by_content_list
from ey_commerce_lib.four_seller.main import FourSellerClient
from ey_commerce_lib.four_seller.schemas.query.order import FourSellerOrderQueryModel
from ey_commerce_lib.takesend.main import TakeSendClient
import ey_commerce_lib.dxm.utils.dxm_commodity_product as dxm_commodity_product_util


async def login_success(user_token: str):
    print(f'user_token: {user_token}')
    pass


@pytest.mark.asyncio
async def test_auto_login_4seller():
    # user_token = await auto_login_4seller(user_name="sky@eeyoung.com", password="ey010203@@")
    # print(user_token)
    async with FourSellerClient(
            user_name="xxxxx",
            password="xxxxxx",
            login_success_call_back=login_success,
            user_token="xxxxxx") as four_seller_client:
        await four_seller_client.list_history_order(FourSellerOrderQueryModel())


cookies = {

}

headers = {

}


@pytest.mark.asyncio
async def test_dxm_api():
    async with (DxmClient(headers=headers, cookies=cookies) as dxm_client):
        # data = await dxm_client.list_order_detail_async(query=ORDER_SEARCH_HAVE_GOODS_BASE_FORM)
        # for order in data:
        #     for pair_info in order.get('detail').get('pair_info_list'):
        #         print(pair_info.get('proid'))
        # data = await dxm_client.update_dxm_commodity_front_sku('17773195771232287', 'fuck112')
        data = await dxm_client.tracking_list(TrackingPageListQuery())
        print(len(data))


@pytest.mark.asyncio
async def test_warehouse():
    async with (DxmClient(headers=headers, cookies=cookies) as dxm_client):
        print(await dxm_client.page_warehouse_product(WarehouseProductQuery()))


@pytest.mark.asyncio
async def test_tasksend_api():
    async with (TakeSendClient(username="", password="") as tasksend_client):
        await tasksend_client.login()



from lxml import html


def parse_ebay_product_page(page_html: str):
    tree = html.fromstring(page_html)
    # 获取eBay产【
    ebay_product_items = tree.xpath('//tbody[@id="ebaySysMsg"]/tr')
    for ebay_product_item in ebay_product_items:
        ebay_id = ebay_product_item.xpath('@data-id')
        sku = ebay_product_item.xpath('./td[4]/text()')
        # 获取子表
        sub_table = ebay_product_item.xpath('.//table[@class="in-table-in"]//tr')
        # 获取proId
        pro_id = sub_table[0].xpath('./td[1]/text()')
        # TODO 获取后续逻辑




import math

from ey_commerce_lib.four_seller.schemas.vo.order import FourSellerOrderVO
from ey_commerce_lib.model import Page


def parse_order(data: dict) -> Page[FourSellerOrderVO]:
    # 计算total_page
    page_size = data.get('pageSize')
    total = data.get('total')
    page_number = data.get('pageCurrent')
    total_page = math.ceil(total / page_size) if total > 0 else 0
    return Page(
        records=[FourSellerOrderVO(**record) for record in data.get('records')],
        total=total,
        page_size=page_size,
        page_number=page_number,
        total_page=total_page
    )



from lxml import html

from ey_commerce_lib.utils.list_util import get_str_list_first_not_blank_or_none


def list_1688_purchase_order_number(html_str: str) -> list[str]:
    """
    根据1688采购页面html获取1688采购页面采购单号列表
    :param html_str:
    :return:
    """
    tree = html.fromstring(html_str)
    good_element_list: list[html.HtmlElement] = tree.xpath('//tr[contains(@class, "goodsId")]')
    purchase_order_number_list = list()
    for good_element in good_element_list:
        purchase_order_number_list.append(get_str_list_first_not_blank_or_none(
            good_element.xpath('.//span[@class="limingcentUrlpic"]/text()')))
    return purchase_order_number_list


def list_wait_pay_page_purchase_order_number(html_str: str) -> list[str]:
    """
    根据采购wait_pay_pag这个请求返回html代码获取采购单号列表
    :param html_str:
    :return:
    """
    tree = html.fromstring(html_str)
    good_element_list: list[html.HtmlElement] = tree.xpath('//tr[contains(@class, "goodsId")]')
    purchase_order_number_list = list()
    for good_element in good_element_list:
        purchase_order_number = get_str_list_first_not_blank_or_none(
            good_element.xpath('.//a[@class="limingcentUrlpic"]/text()'))
        purchase_order_number_list.append(purchase_order_number)
    return purchase_order_number_list


def list_purchasing_all(html_str: str) -> list[dict]:
    """
       根据采购全部页面html，获取采购页面详细数据列表
       :param html_str:
       :return:
       """
    tree = html.fromstring(html_str)
    good_element_list: list[html.HtmlElement] = tree.xpath('//tr[contains(@class, "goodsId")]')
    purchase_result = list()
    for good_element in good_element_list:
        purchase_id = get_str_list_first_not_blank_or_none(good_element.xpath('@id'))
        purchase_order_number = get_str_list_first_not_blank_or_none(
            good_element.xpath('.//a[@class="limingcentUrlpic"]/text()'))
        ghs_id = get_str_list_first_not_blank_or_none(
            good_element.xpath('.//span[contains(@class, "ghsHoverPrompt")]/@data-ghsid'))
        ghs_name = get_str_list_first_not_blank_or_none(
            good_element.xpath('.//span[contains(@class, "ghsHoverPrompt")]/span/text()'))
        warehouse_name, purchase_info = good_element.xpath('.//td[4]/span/text()')[0].strip().split('|')
        agent_name = purchase_info.split('：')[1]
        # 获取兄弟元素
        content_element = good_element.getnext()
        # 获取商品信息
        img = get_str_list_first_not_blank_or_none(content_element.xpath('.//img/@data-original'))
        content_number_info = content_element.xpath('./td[2]/text()')
        product_zl_number = None
        purchase_number = None
        for content_number in content_number_info:
            content_number = content_number.strip()
            if content_number.split('：')[0] == '商品种类':
                product_zl_number = content_number.split('：')[1].strip()
            elif content_number.split('：')[0] == '采购数量':
                purchase_number = content_number.split('：')[1].strip()
        # 解析出货款
        total_amount = get_str_list_first_not_blank_or_none(content_element.xpath('./td[3]//input/@data-totalamount'))
        # 运费
        shipping_amount = get_str_list_first_not_blank_or_none(content_element.xpath('./td[3]//input/@value'))
        source = None
        source_list = content_element.xpath('./td[4]/span[1]')
        if len(source_list) == 0:
            # 说明不是淘供销
            source_list = content_element.xpath('./td[4]/div[1]')

        if len(source_list) > 0:
            try:
                source = source_list[0].text_content()
                source = source.strip()
                platform, source_str = source.split("：")
                source = platform.strip() + ":" + source_str.strip()
            except:
                source = None
        # 获取物流信息
        track_element_list = content_element.xpath('./td[4]//a[@class="getLogisticsMsgBox"]')
        track_list = list()
        for track_element in track_element_list:
            tracking_id = get_str_list_first_not_blank_or_none(track_element.xpath("@trackingid"))
            tracking_number = get_str_list_first_not_blank_or_none(track_element.xpath("@data-trackingnumber"))
            tracking_code = get_str_list_first_not_blank_or_none(track_element.xpath("@data-trackingcode"))
            track_status = get_str_list_first_not_blank_or_none(
                track_element.xpath('./span[contains(@class, "iconfont")]/@data-original-title'))
            track_list.append({
                "tracking_id": tracking_id,
                "tracking_number": tracking_number,
                "tracking_code": tracking_code,
                "track_status": track_status
            })

        # 状态
        status = get_str_list_first_not_blank_or_none(content_element.xpath('./td[6]/div[@class="mBottom3"]/text()'))
        purchase_result.append({
            "purchase_id": purchase_id,
            "purchase_order_number": purchase_order_number,
            "ghs_id": ghs_id,
            "ghs_name": ghs_name,
            "agent_name": agent_name,
            "img": img,
            "product_zl_number": product_zl_number,
            "purchase_number": purchase_number,
            "total_amount": total_amount,
            "shipping_amount": shipping_amount,
            "source": source,
            "status": status,
            'track_list': track_list
        })

    return purchase_result



from pydantic import BaseModel, Field, ConfigDict


class DxmEbayProductModel(BaseModel):
    page_no: str = Field(default='', alias='pageNo', description="页码")
    page_size: str = Field(default='', alias='pageSize', description="每页数量")
    shop_id: str = Field(default=-1, alias='shopId', description="店铺ID 全部:-1")
    shop_group_id: str = Field(default='', alias='shopGroupId')
    full_cid: str = Field(default='', alias='fullCid')
    dxm_state: str = Field(default='online', alias='dxmState', description="店小秘在线状态 online/offline")
    dxm_offline_state: str = Field(default='', alias='dxmOfflineState', description="店小秘离线状态")
    search_type: str = Field(default='1', alias='searchType', description="搜索类型(1:标题-3:sku-4:SubSku)")
    search_value: str = Field(default='', alias='searchValue', description="搜索内容")
    sort_name: str = Field(default='', alias='sortName', description="排序字段")
    sort_value: str = Field(default='0', alias='sortValue', description="排序内容")
    sell_ype: str = Field(default='0', alias='sellType', description="售卖形式 全部:0,拍卖:'1'具体参照页面")
    listing_status: str = Field(default='', alias='listingStatus')
    advanced_search: str = Field(default='yes', alias='advancedSearch')
    price_lift: str = Field(default='', alias='priceLift')
    price_right: str = Field(default='', alias='priceRight')
    inventory_lift: str = Field(default='', alias='inventoryLift')
    inventory_right: str = Field(default='', alias='inventoryRight')
    save_lift: str = Field(default='', alias='saveLift')
    save_right: str = Field(default='', alias='saveRight')
    sold_lift: str = Field(default='', alias='soldLift')
    sold_right: str = Field(default='', alias='soldRight')
    time_lift: str = Field(default='', alias='timeLift')
    time_right: str = Field(default='', alias='timeRight')
    hit_count_lift: str = Field(default='', alias='hitCountLift')
    hit_count_right: str = Field(default='', alias='hitCountRight')
    listing_duration: str = Field(default='', alias='listingDuration')
    dispatch_time_max: str = Field(default='', alias='dispatchTimeMax')
    paypal: str = Field(default='', alias='paypal')
    gpsr_manufacturer: str = Field(default='-1', alias='gpsrManufacturer')
    gpsr_responsible_persons: str = Field(default='-1', alias='gpsrResponsiblePersons')
    gpsr_safety: str = Field(default='-1', alias='gpsrSafety')
    gpsr_documents: str = Field(default='-1', alias='gpsrDocuments')
    gpsr_document_status: str = Field(default='-1', alias='gpsrDocumentStatus')
    country: str = Field(default='', alias='country')
    advanced_time: str = Field(default='1', alias='advancedTime')
    source_url: str = Field(default='', alias='sourceUrl')
    product_search_type: str = Field(default='1', alias='productSearchType')
    site: str = Field(default='', alias='site', description="站点(国家代码 例如US )")
    product_category_id: str = Field(default='', alias='productCategoryId')
    store_category_id: str = Field(default='0', alias='storeCategoryId')
    location_name: str = Field(default='', alias='locationName')
    video_sel: str = Field(default='-1', alias='videoSel')
    comment_type: str = Field(default='0', alias='commentType')
    comment_content: str = Field(default='', alias='commentContent')
    vat_percent_type: str = Field(default='', alias='vatPercentType')
    motor_state: str = Field(default='0', alias='motorState')

    model_config = ConfigDict(
        populate_by_name=True,
        title="店小秘ebay在线产品查询模型"
    )
